// Gmsh - Copyright (C) 1997-2009 C. Geuzaine, J.-F. Remacle
//
// See the LICENSE.txt file for license information. Please report all
// bugs and problems to <gmsh@geuz.org>.

#include "GModel.h"
#include "GmshEmbedded.h"

CTX *CTX::_instance = 0;

int GmshInitialize(int argc, char **argv)
{
}

int GmshFinalize()
{
}
